@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-08'; # DATE
+our $DATE = '2022-10-09'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
@@ -253,6 +253,12 @@ sub _select_single {
                                     $r = {%$r0};
                                 }
 
+                                # precompile regexes
+                                require Regexp::From::String;
+                                if (defined $r->{field_name_matches}) {
+                                    $r->{field_name_matches} = Regexp::From::String::str_to_re({case_insensitive=>1}, $r->{field_name_matches});
+                                }
+
                                 if ($r->{formatters} && @{ $r->{formatters} }) {
                                     my @filter_names2;
                                     for my $f (@{ $r->{formatters} }) {
@@ -290,14 +296,12 @@ sub _select_single {
                             $i++;
                             my $matches = 1;
                             if (defined $r->{field_name_matches}) {
-                                require Regexp::From::String;
-                                $r->{field_name_matches} = Regexp::From::String::str_to_re({case_insensitive=>1}, $r->{field_name_matches});
                                 $field_name0 =~ $r->{field_name_matches} or do {
                                     $matches = 0;
                                     log_trace "Skipping default_formatter_rules[%d]: field_name_matches %s doesn't match %s", $i, $r->{field_name_matches}, $field_name0;
                                     next RULE;
                                 };
-                            } # XXX precompile field_name_matches
+                            }
                             log_trace "Using formatters from default_formatter_rules[%d] (%s) for field name %s", $i, $r->{formatters}, $field_name0;
                             $default_formatter = $r->{formatter};
                             last RULE;
@@ -427,7 +431,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.009 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-08.
+This document describes version 0.010 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-09.
 
 =head1 SYNOPSIS
 
